aboutsummaryrefslogtreecommitdiffstats
path: root/keyboards/handwired/jtallbean
diff options
context:
space:
mode:
authorRyan2024-05-03 07:21:29 +0200
committerGitHub2024-05-03 07:21:29 +0200
commitd09a06a1b354760fd0e64a453abade972900e885 (patch)
tree88d94640f4507ac8d7f570607423825bec3c6f89 /keyboards/handwired/jtallbean
parent5426a7a129acf2ff5c8b435014747f1238e17965 (diff)
Update GPIO API usage in keyboard code (#23361)
Diffstat (limited to 'keyboards/handwired/jtallbean')
-rw-r--r--keyboards/handwired/jtallbean/split_65/split_65.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/keyboards/handwired/jtallbean/split_65/split_65.c b/keyboards/handwired/jtallbean/split_65/split_65.c
index d408f5577b..b75b12137f 100644
--- a/keyboards/handwired/jtallbean/split_65/split_65.c
+++ b/keyboards/handwired/jtallbean/split_65/split_65.c
@@ -25,8 +25,8 @@ void matrix_init_kb(void) {
// runs once when the firmware starts up
// Set our LED pins as output
- setPinOutput(B0);
- writePinLow(B0);
+ gpio_set_pin_output(B0);
+ gpio_write_pin_low(B0);
matrix_init_user();
}
@@ -36,8 +36,8 @@ bool led_update_kb(led_t led_state) {
bool res = led_update_user(led_state);
if(res) {
- // writePin sets the pin high for 1 and low for 0.
- writePin(B0, led_state.caps_lock);
+ // gpio_write_pin sets the pin high for 1 and low for 0.
+ gpio_write_pin(B0, led_state.caps_lock);
}
return res;
}